import { purryOn } from "./_purryOn";
export function conditional(...args) {
    return purryOn(isCase, conditionalImplementation, args);
}
function conditionalImplementation(data, ...cases) {
    for (const [when, then] of cases) {
        if (when(data)) {
            return then(data);
        }
    }
    throw new Error("conditional: data failed for all cases");
}
function isCase(maybeCase) {
    if (!Array.isArray(maybeCase)) {
        return false;
    }
    const [when, then, ...rest] = maybeCase;
    return (typeof when === "function" &&
        when.length <= 1 &&
        typeof then === "function" &&
        then.length <= 1 &&
        rest.length === 0);
}
(function (conditional) {
    conditional.defaultCase = (then = trivialDefaultCase) => [() => true, then];
})(conditional || (conditional = {}));
const trivialDefaultCase = () => undefined;
