import { purry } from "./purry";
export function isDeepEqual(...args) {
    return purry(isDeepEqualImplementation, args);
}
function isDeepEqualImplementation(data, other) {
    if (data === other) {
        return true;
    }
    if (Object.is(data, other)) {
        return true;
    }
    if (typeof data !== "object" || typeof other !== "object") {
        return false;
    }
    if (data === null || other === null) {
        return false;
    }
    if (Object.getPrototypeOf(data) !== Object.getPrototypeOf(other)) {
        return false;
    }
    if (Array.isArray(data)) {
        if (data.length !== other.length) {
            return false;
        }
        for (const [index, item] of data.entries()) {
            if (!isDeepEqualImplementation(item, other[index])) {
                return false;
            }
        }
        return true;
    }
    if (data instanceof Date) {
        return data.getTime() === other.getTime();
    }
    if (data instanceof RegExp) {
        return data.toString() === other.toString();
    }
    const keys = Object.keys(data);
    if (keys.length !== Object.keys(other).length) {
        return false;
    }
    for (const key of keys) {
        if (!Object.prototype.hasOwnProperty.call(other, key)) {
            return false;
        }
        if (!isDeepEqualImplementation(data[key], other[key])) {
            return false;
        }
    }
    return true;
}
